@@ -14,7 +14,7 @@ Usage::
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING
+from typing import Any, Dict, List, TYPE_CHECKING, Type
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_backup.type_defs import (
     BackupPlanInputTypeDef,
@@ -68,27 +68,27 @@ __all__ = ("BackupClient",)
 
 
 class Exceptions:
-    AlreadyExistsException: Boto3ClientError
-    ClientError: Boto3ClientError
-    DependencyFailureException: Boto3ClientError
-    InvalidParameterValueException: Boto3ClientError
-    InvalidRequestException: Boto3ClientError
-    LimitExceededException: Boto3ClientError
-    MissingParameterValueException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
-    ServiceUnavailableException: Boto3ClientError
+    AlreadyExistsException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    DependencyFailureException: Type[Boto3ClientError]
+    InvalidParameterValueException: Type[Boto3ClientError]
+    InvalidRequestException: Type[Boto3ClientError]
+    LimitExceededException: Type[Boto3ClientError]
+    MissingParameterValueException: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
+    ServiceUnavailableException: Type[Boto3ClientError]
 
 
 class BackupClient:
     """
-    [Backup.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client)
+    [Backup.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.can_paginate)
         """
 
     def create_backup_plan(
@@ -98,7 +98,7 @@ class BackupClient:
         CreatorRequestId: str = None,
     ) -> CreateBackupPlanOutputTypeDef:
         """
-        [Client.create_backup_plan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.create_backup_plan)
+        [Client.create_backup_plan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.create_backup_plan)
         """
 
     def create_backup_selection(
@@ -108,7 +108,7 @@ class BackupClient:
         CreatorRequestId: str = None,
     ) -> CreateBackupSelectionOutputTypeDef:
         """
-        [Client.create_backup_selection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.create_backup_selection)
+        [Client.create_backup_selection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.create_backup_selection)
         """
 
     def create_backup_vault(
@@ -119,78 +119,78 @@ class BackupClient:
         CreatorRequestId: str = None,
     ) -> CreateBackupVaultOutputTypeDef:
         """
-        [Client.create_backup_vault documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.create_backup_vault)
+        [Client.create_backup_vault documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.create_backup_vault)
         """
 
     def delete_backup_plan(self, BackupPlanId: str) -> DeleteBackupPlanOutputTypeDef:
         """
-        [Client.delete_backup_plan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.delete_backup_plan)
+        [Client.delete_backup_plan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.delete_backup_plan)
         """
 
     def delete_backup_selection(self, BackupPlanId: str, SelectionId: str) -> None:
         """
-        [Client.delete_backup_selection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.delete_backup_selection)
+        [Client.delete_backup_selection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.delete_backup_selection)
         """
 
     def delete_backup_vault(self, BackupVaultName: str) -> None:
         """
-        [Client.delete_backup_vault documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.delete_backup_vault)
+        [Client.delete_backup_vault documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.delete_backup_vault)
         """
 
     def delete_backup_vault_access_policy(self, BackupVaultName: str) -> None:
         """
-        [Client.delete_backup_vault_access_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.delete_backup_vault_access_policy)
+        [Client.delete_backup_vault_access_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.delete_backup_vault_access_policy)
         """
 
     def delete_backup_vault_notifications(self, BackupVaultName: str) -> None:
         """
-        [Client.delete_backup_vault_notifications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.delete_backup_vault_notifications)
+        [Client.delete_backup_vault_notifications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.delete_backup_vault_notifications)
         """
 
     def delete_recovery_point(self, BackupVaultName: str, RecoveryPointArn: str) -> None:
         """
-        [Client.delete_recovery_point documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.delete_recovery_point)
+        [Client.delete_recovery_point documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.delete_recovery_point)
         """
 
     def describe_backup_job(self, BackupJobId: str) -> DescribeBackupJobOutputTypeDef:
         """
-        [Client.describe_backup_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.describe_backup_job)
+        [Client.describe_backup_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.describe_backup_job)
         """
 
     def describe_backup_vault(self, BackupVaultName: str) -> DescribeBackupVaultOutputTypeDef:
         """
-        [Client.describe_backup_vault documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.describe_backup_vault)
+        [Client.describe_backup_vault documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.describe_backup_vault)
         """
 
     def describe_copy_job(self, CopyJobId: str) -> DescribeCopyJobOutputTypeDef:
         """
-        [Client.describe_copy_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.describe_copy_job)
+        [Client.describe_copy_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.describe_copy_job)
         """
 
     def describe_protected_resource(
         self, ResourceArn: str
     ) -> DescribeProtectedResourceOutputTypeDef:
         """
-        [Client.describe_protected_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.describe_protected_resource)
+        [Client.describe_protected_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.describe_protected_resource)
         """
 
     def describe_recovery_point(
         self, BackupVaultName: str, RecoveryPointArn: str
     ) -> DescribeRecoveryPointOutputTypeDef:
         """
-        [Client.describe_recovery_point documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.describe_recovery_point)
+        [Client.describe_recovery_point documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.describe_recovery_point)
         """
 
     def describe_restore_job(self, RestoreJobId: str) -> DescribeRestoreJobOutputTypeDef:
         """
-        [Client.describe_restore_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.describe_restore_job)
+        [Client.describe_restore_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.describe_restore_job)
         """
 
     def export_backup_plan_template(
         self, BackupPlanId: str
     ) -> ExportBackupPlanTemplateOutputTypeDef:
         """
-        [Client.export_backup_plan_template documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.export_backup_plan_template)
+        [Client.export_backup_plan_template documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.export_backup_plan_template)
         """
 
     def generate_presigned_url(
@@ -201,61 +201,61 @@ class BackupClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.generate_presigned_url)
         """
 
     def get_backup_plan(
         self, BackupPlanId: str, VersionId: str = None
     ) -> GetBackupPlanOutputTypeDef:
         """
-        [Client.get_backup_plan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.get_backup_plan)
+        [Client.get_backup_plan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.get_backup_plan)
         """
 
     def get_backup_plan_from_json(
         self, BackupPlanTemplateJson: str
     ) -> GetBackupPlanFromJSONOutputTypeDef:
         """
-        [Client.get_backup_plan_from_json documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.get_backup_plan_from_json)
+        [Client.get_backup_plan_from_json documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.get_backup_plan_from_json)
         """
 
     def get_backup_plan_from_template(
         self, BackupPlanTemplateId: str
     ) -> GetBackupPlanFromTemplateOutputTypeDef:
         """
-        [Client.get_backup_plan_from_template documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.get_backup_plan_from_template)
+        [Client.get_backup_plan_from_template documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.get_backup_plan_from_template)
         """
 
     def get_backup_selection(
         self, BackupPlanId: str, SelectionId: str
     ) -> GetBackupSelectionOutputTypeDef:
         """
-        [Client.get_backup_selection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.get_backup_selection)
+        [Client.get_backup_selection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.get_backup_selection)
         """
 
     def get_backup_vault_access_policy(
         self, BackupVaultName: str
     ) -> GetBackupVaultAccessPolicyOutputTypeDef:
         """
-        [Client.get_backup_vault_access_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.get_backup_vault_access_policy)
+        [Client.get_backup_vault_access_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.get_backup_vault_access_policy)
         """
 
     def get_backup_vault_notifications(
         self, BackupVaultName: str
     ) -> GetBackupVaultNotificationsOutputTypeDef:
         """
-        [Client.get_backup_vault_notifications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.get_backup_vault_notifications)
+        [Client.get_backup_vault_notifications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.get_backup_vault_notifications)
         """
 
     def get_recovery_point_restore_metadata(
         self, BackupVaultName: str, RecoveryPointArn: str
     ) -> GetRecoveryPointRestoreMetadataOutputTypeDef:
         """
-        [Client.get_recovery_point_restore_metadata documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.get_recovery_point_restore_metadata)
+        [Client.get_recovery_point_restore_metadata documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.get_recovery_point_restore_metadata)
         """
 
     def get_supported_resource_types(self) -> GetSupportedResourceTypesOutputTypeDef:
         """
-        [Client.get_supported_resource_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.get_supported_resource_types)
+        [Client.get_supported_resource_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.get_supported_resource_types)
         """
 
     def list_backup_jobs(
@@ -272,42 +272,42 @@ class BackupClient:
         ByResourceType: str = None,
     ) -> ListBackupJobsOutputTypeDef:
         """
-        [Client.list_backup_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.list_backup_jobs)
+        [Client.list_backup_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.list_backup_jobs)
         """
 
     def list_backup_plan_templates(
         self, NextToken: str = None, MaxResults: int = None
     ) -> ListBackupPlanTemplatesOutputTypeDef:
         """
-        [Client.list_backup_plan_templates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.list_backup_plan_templates)
+        [Client.list_backup_plan_templates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.list_backup_plan_templates)
         """
 
     def list_backup_plan_versions(
         self, BackupPlanId: str, NextToken: str = None, MaxResults: int = None
     ) -> ListBackupPlanVersionsOutputTypeDef:
         """
-        [Client.list_backup_plan_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.list_backup_plan_versions)
+        [Client.list_backup_plan_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.list_backup_plan_versions)
         """
 
     def list_backup_plans(
         self, NextToken: str = None, MaxResults: int = None, IncludeDeleted: bool = None
     ) -> ListBackupPlansOutputTypeDef:
         """
-        [Client.list_backup_plans documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.list_backup_plans)
+        [Client.list_backup_plans documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.list_backup_plans)
         """
 
     def list_backup_selections(
         self, BackupPlanId: str, NextToken: str = None, MaxResults: int = None
     ) -> ListBackupSelectionsOutputTypeDef:
         """
-        [Client.list_backup_selections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.list_backup_selections)
+        [Client.list_backup_selections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.list_backup_selections)
         """
 
     def list_backup_vaults(
         self, NextToken: str = None, MaxResults: int = None
     ) -> ListBackupVaultsOutputTypeDef:
         """
-        [Client.list_backup_vaults documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.list_backup_vaults)
+        [Client.list_backup_vaults documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.list_backup_vaults)
         """
 
     def list_copy_jobs(
@@ -322,14 +322,14 @@ class BackupClient:
         ByDestinationVaultArn: str = None,
     ) -> ListCopyJobsOutputTypeDef:
         """
-        [Client.list_copy_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.list_copy_jobs)
+        [Client.list_copy_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.list_copy_jobs)
         """
 
     def list_protected_resources(
         self, NextToken: str = None, MaxResults: int = None
     ) -> ListProtectedResourcesOutputTypeDef:
         """
-        [Client.list_protected_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.list_protected_resources)
+        [Client.list_protected_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.list_protected_resources)
         """
 
     def list_recovery_points_by_backup_vault(
@@ -344,33 +344,33 @@ class BackupClient:
         ByCreatedAfter: datetime = None,
     ) -> ListRecoveryPointsByBackupVaultOutputTypeDef:
         """
-        [Client.list_recovery_points_by_backup_vault documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.list_recovery_points_by_backup_vault)
+        [Client.list_recovery_points_by_backup_vault documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.list_recovery_points_by_backup_vault)
         """
 
     def list_recovery_points_by_resource(
         self, ResourceArn: str, NextToken: str = None, MaxResults: int = None
     ) -> ListRecoveryPointsByResourceOutputTypeDef:
         """
-        [Client.list_recovery_points_by_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.list_recovery_points_by_resource)
+        [Client.list_recovery_points_by_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.list_recovery_points_by_resource)
         """
 
     def list_restore_jobs(
         self, NextToken: str = None, MaxResults: int = None
     ) -> ListRestoreJobsOutputTypeDef:
         """
-        [Client.list_restore_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.list_restore_jobs)
+        [Client.list_restore_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.list_restore_jobs)
         """
 
     def list_tags(
         self, ResourceArn: str, NextToken: str = None, MaxResults: int = None
     ) -> ListTagsOutputTypeDef:
         """
-        [Client.list_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.list_tags)
+        [Client.list_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.list_tags)
         """
 
     def put_backup_vault_access_policy(self, BackupVaultName: str, Policy: str = None) -> None:
         """
-        [Client.put_backup_vault_access_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.put_backup_vault_access_policy)
+        [Client.put_backup_vault_access_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.put_backup_vault_access_policy)
         """
 
     def put_backup_vault_notifications(
@@ -398,7 +398,7 @@ class BackupClient:
         ],
     ) -> None:
         """
-        [Client.put_backup_vault_notifications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.put_backup_vault_notifications)
+        [Client.put_backup_vault_notifications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.put_backup_vault_notifications)
         """
 
     def start_backup_job(
@@ -413,7 +413,7 @@ class BackupClient:
         RecoveryPointTags: Dict[str, str] = None,
     ) -> StartBackupJobOutputTypeDef:
         """
-        [Client.start_backup_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.start_backup_job)
+        [Client.start_backup_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.start_backup_job)
         """
 
     def start_copy_job(
@@ -426,7 +426,7 @@ class BackupClient:
         Lifecycle: LifecycleTypeDef = None,
     ) -> StartCopyJobOutputTypeDef:
         """
-        [Client.start_copy_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.start_copy_job)
+        [Client.start_copy_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.start_copy_job)
         """
 
     def start_restore_job(
@@ -438,34 +438,34 @@ class BackupClient:
         ResourceType: str = None,
     ) -> StartRestoreJobOutputTypeDef:
         """
-        [Client.start_restore_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.start_restore_job)
+        [Client.start_restore_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.start_restore_job)
         """
 
     def stop_backup_job(self, BackupJobId: str) -> None:
         """
-        [Client.stop_backup_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.stop_backup_job)
+        [Client.stop_backup_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.stop_backup_job)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeyList: List[str]) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.untag_resource)
         """
 
     def update_backup_plan(
         self, BackupPlanId: str, BackupPlan: BackupPlanInputTypeDef
     ) -> UpdateBackupPlanOutputTypeDef:
         """
-        [Client.update_backup_plan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.update_backup_plan)
+        [Client.update_backup_plan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.update_backup_plan)
         """
 
     def update_recovery_point_lifecycle(
         self, BackupVaultName: str, RecoveryPointArn: str, Lifecycle: LifecycleTypeDef = None
     ) -> UpdateRecoveryPointLifecycleOutputTypeDef:
         """
-        [Client.update_recovery_point_lifecycle documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/backup.html#Backup.Client.update_recovery_point_lifecycle)
+        [Client.update_recovery_point_lifecycle documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.37/reference/services/backup.html#Backup.Client.update_recovery_point_lifecycle)
         """
